pub fn delete(
name: &str,
delete_branch: bool,
force: bool,
config: &Config,
cwd: &Path,
) -> Result<()>Expand description
Delete a worktree for the current project.
If delete_branch is true, the local branch is deleted without prompting.
Otherwise, if a terminal is attached, the user is prompted.
If force is true, worktrees with uncommitted changes are removed anyway.
Without --force, dirty worktrees cause an error.